@@ -1,21 +1,26 @@
+import random 
+import pandas as pd
 import numpy as np
-from DBDIpy import plot_adducts
+#import DBDIpy as dbdi
 
 
 def test_plot_adducts():
-    reference_scores = np.random.random((100, 100))
-    comparison_scores = np.random.random((100, 100))
-    fig = create_confusion_matrix_plot(reference_scores, comparison_scores)
+    
+    testID = random.sample(range(1, 99), 3)
+    testdata = pd.DataFrame(np.random.randint(100, 1000000, size = (100, 100)))
+    
+    
+    fig = plot_adducts(testID, testdata, metadata = None, transform = False)
+    
     assert fig is not None
-    assert fig.get_axes()[0].get_xlabel() == "MS2DeepScore"
-    assert fig.get_axes()[0].get_ylabel() == 'Tanimoto similarity'
-    
+   
     
     
     
     
     
     
+"""    
 import numpy as np
 from ms2deepscore.plotting import create_confusion_matrix_plot
 
@@ -26,4 +31,5 @@ def test_create_confusion_matrix_plot():
     fig = create_confusion_matrix_plot(reference_scores, comparison_scores)
     assert fig is not None
     assert fig.get_axes()[0].get_xlabel() == "MS2DeepScore"
-    assert fig.get_axes()[0].get_ylabel() == 'Tanimoto similarity'
\ No newline at end of file
+    assert fig.get_axes()[0].get_ylabel() == 'Tanimoto similarity'
+"""
\ No newline at end of file
